# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_cargo_shuttle_global_optspecs
	string join \n h/help
end

function __fish_cargo_shuttle_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_cargo_shuttle_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_cargo_shuttle_using_subcommand
	set -l cmd (__fish_cargo_shuttle_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c cargo-shuttle -n "__fish_cargo_shuttle_needs_command" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_needs_command" -f -a "init" -d 'Create a new Shuttle project'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_needs_command" -f -a "run" -d 'Run a Shuttle service locally'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_needs_command" -f -a "deploy" -d 'Deploy a Shuttle service'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_needs_command" -f -a "deployment" -d 'Manage deployments of a Shuttle service'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_needs_command" -f -a "status" -d 'View the status of a Shuttle service'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_needs_command" -f -a "stop" -d 'Stop this Shuttle service'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_needs_command" -f -a "logs" -d 'View the logs of a deployment in this Shuttle service'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_needs_command" -f -a "project" -d 'List or manage projects on Shuttle'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_needs_command" -f -a "resource" -d 'Manage resources of a Shuttle project'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_needs_command" -f -a "clean" -d 'Remove cargo build artifacts in the Shuttle environment'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_needs_command" -f -a "login" -d 'Login to the Shuttle platform'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_needs_command" -f -a "logout" -d 'Log out of the Shuttle platform'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_needs_command" -f -a "generate" -d 'Generate shell completions and man page'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_needs_command" -f -a "feedback" -d 'Open an issue on GitHub and provide feedback'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand init" -s t -l template -d 'Clone a starter template from Shuttle\'s official examples' -r -f -a "{axum\t'Axum - Modular web framework from the Tokio ecosystem',actix-web\t'Actix Web - Powerful and fast web framework',rocket\t'Rocket - Simple and easy-to-use web framework',loco\t'Loco - Batteries included web framework based on Axum',salvo\t'Salvo - Powerful and simple web framework',poem\t'Poem - Full-featured and easy-to-use web framework',poise\t'Poise - Discord Bot framework with good slash command support',serenity\t'Serenity - Discord Bot framework',tower\t'Tower - Modular service library',thruster\t'Thruster - Web framework',tide\t'Tide - Web framework',warp\t'Warp - Web framework',none\t'No template - Make a custom service'}"
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand init" -l from -d 'Clone a template from a git repository or local path using cargo-generate' -r
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand init" -l subfolder -d 'Path to the template in the source (used with --from)' -r
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand init" -l api-key -d 'API key for the Shuttle platform' -r
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand init" -l force-name -d 'Don\'t check the project name\'s validity or availability and use it anyways'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand init" -l create-env -d 'Whether to start the container for this project on Shuttle, and claim the project name'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand init" -l no-git -d 'Don\'t initialize a new git repository'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand init" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand run" -s p -l port -d 'Port to start service on' -r
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand run" -l secrets -d 'Use this secrets file instead' -r -F
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand run" -l external -d 'Use 0.0.0.0 instead of localhost (for usage with local external devices)'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand run" -s r -l release -d 'Use release mode for building the project'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand run" -l raw -d 'Don\'t display timestamps and log origin tags'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand run" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deploy" -s i -l image -d 'BETA: Deploy this Docker image instead of building one' -r
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deploy" -l output-archive -d 'Output the deployment archive to a file instead of sending a deployment request' -r -F
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deploy" -l secrets -d 'Use this secrets file instead' -r -F
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deploy" -l no-follow -l nf -d 'BETA: Don\'t follow the deployment status, exit after the deployment begins'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deploy" -l allow-dirty -l ad -d 'Allow deployment with uncommitted files'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deploy" -l no-test -l nt -d 'Don\'t run pre-deploy tests'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deploy" -l raw -d 'Don\'t display timestamps and log origin tags'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deploy" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deployment; and not __fish_seen_subcommand_from list status stop help" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deployment; and not __fish_seen_subcommand_from list status stop help" -f -a "list" -d 'List all the deployments for a service'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deployment; and not __fish_seen_subcommand_from list status stop help" -f -a "status" -d 'View status of a deployment'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deployment; and not __fish_seen_subcommand_from list status stop help" -f -a "stop" -d 'BETA: Stop running deployment(s)'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deployment; and not __fish_seen_subcommand_from list status stop help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deployment; and __fish_seen_subcommand_from list" -l page -d 'Which page to display' -r
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deployment; and __fish_seen_subcommand_from list" -l limit -d 'How many projects per page to display' -r
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deployment; and __fish_seen_subcommand_from list" -l raw -d 'Output table without borders'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deployment; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deployment; and __fish_seen_subcommand_from status" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deployment; and __fish_seen_subcommand_from stop" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deployment; and __fish_seen_subcommand_from help" -f -a "list" -d 'List all the deployments for a service'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deployment; and __fish_seen_subcommand_from help" -f -a "status" -d 'View status of a deployment'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deployment; and __fish_seen_subcommand_from help" -f -a "stop" -d 'BETA: Stop running deployment(s)'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand deployment; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand status" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand stop" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand logs" -l head -d 'View the first N log lines' -r
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand logs" -l tail -d 'View the last N log lines' -r
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand logs" -s l -l latest -d 'View logs from the most recent deployment (which is not always the latest running one)'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand logs" -s f -l follow -d 'Follow log output'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand logs" -l raw -d 'Don\'t display timestamps and log origin tags'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand logs" -l all -d 'View all log lines'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand logs" -l all-deployments -d 'Get logs from all deployments instead of one deployment'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand logs" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and not __fish_seen_subcommand_from start create status stop restart list delete help" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and not __fish_seen_subcommand_from start create status stop restart list delete help" -f -a "start" -d 'Create an environment for this project on Shuttle'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and not __fish_seen_subcommand_from start create status stop restart list delete help" -f -a "create" -d 'Create an environment for this project on Shuttle'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and not __fish_seen_subcommand_from start create status stop restart list delete help" -f -a "status" -d 'Check the status of this project\'s environment on Shuttle'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and not __fish_seen_subcommand_from start create status stop restart list delete help" -f -a "stop" -d 'Destroy this project\'s environment (container) on Shuttle'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and not __fish_seen_subcommand_from start create status stop restart list delete help" -f -a "restart" -d 'Destroy and create an environment for this project on Shuttle'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and not __fish_seen_subcommand_from start create status stop restart list delete help" -f -a "list" -d 'List all projects you have access to'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and not __fish_seen_subcommand_from start create status stop restart list delete help" -f -a "delete" -d 'Delete a project and all linked data'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and not __fish_seen_subcommand_from start create status stop restart list delete help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from start" -l idle-minutes -d 'How long to wait before putting the project in an idle state due to inactivity. 0 means the project will never idle' -r
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from start" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from create" -l idle-minutes -d 'How long to wait before putting the project in an idle state due to inactivity. 0 means the project will never idle' -r
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from create" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from status" -s f -l follow -d 'Follow status of project command'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from status" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from stop" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from restart" -l idle-minutes -d 'How long to wait before putting the project in an idle state due to inactivity. 0 means the project will never idle' -r
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from restart" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from list" -l page -d '(deprecated) Which page to display' -r
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from list" -l limit -d '(deprecated) How many projects per page to display' -r
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from list" -l raw -d 'Output table without borders'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from delete" -s y -l yes -d 'Skip confirmations and proceed'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from help" -f -a "start" -d 'Create an environment for this project on Shuttle'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from help" -f -a "status" -d 'Check the status of this project\'s environment on Shuttle'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from help" -f -a "stop" -d 'Destroy this project\'s environment (container) on Shuttle'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from help" -f -a "restart" -d 'Destroy and create an environment for this project on Shuttle'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from help" -f -a "list" -d 'List all projects you have access to'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Delete a project and all linked data'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand project; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand resource; and not __fish_seen_subcommand_from list delete help" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand resource; and not __fish_seen_subcommand_from list delete help" -f -a "list" -d 'List all the resources for a project'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand resource; and not __fish_seen_subcommand_from list delete help" -f -a "delete" -d 'Delete a resource'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand resource; and not __fish_seen_subcommand_from list delete help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand resource; and __fish_seen_subcommand_from list" -l raw -d 'Output table without borders'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand resource; and __fish_seen_subcommand_from list" -l show-secrets -d 'Show secrets from resources (e.g. a password in a connection string)'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand resource; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand resource; and __fish_seen_subcommand_from delete" -s y -l yes -d 'Skip confirmations and proceed'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand resource; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand resource; and __fish_seen_subcommand_from help" -f -a "list" -d 'List all the resources for a project'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand resource; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Delete a resource'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand resource; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand clean" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand login" -l api-key -d 'API key for the Shuttle platform' -r
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand login" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand logout" -l reset-api-key -d 'Reset the API key before logging out'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand logout" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand generate; and not __fish_seen_subcommand_from shell manpage help" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand generate; and not __fish_seen_subcommand_from shell manpage help" -f -a "shell" -d 'Generate shell completions'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand generate; and not __fish_seen_subcommand_from shell manpage help" -f -a "manpage" -d 'Generate man page to the standard output'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand generate; and not __fish_seen_subcommand_from shell manpage help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand generate; and __fish_seen_subcommand_from shell" -s o -l output -d 'Output to a file (stdout by default)' -r -F
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand generate; and __fish_seen_subcommand_from shell" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand generate; and __fish_seen_subcommand_from manpage" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand generate; and __fish_seen_subcommand_from help" -f -a "shell" -d 'Generate shell completions'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand generate; and __fish_seen_subcommand_from help" -f -a "manpage" -d 'Generate man page to the standard output'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand generate; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand feedback" -s h -l help -d 'Print help'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and not __fish_seen_subcommand_from init run deploy deployment status stop logs project resource clean login logout generate feedback help" -f -a "init" -d 'Create a new Shuttle project'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and not __fish_seen_subcommand_from init run deploy deployment status stop logs project resource clean login logout generate feedback help" -f -a "run" -d 'Run a Shuttle service locally'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and not __fish_seen_subcommand_from init run deploy deployment status stop logs project resource clean login logout generate feedback help" -f -a "deploy" -d 'Deploy a Shuttle service'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and not __fish_seen_subcommand_from init run deploy deployment status stop logs project resource clean login logout generate feedback help" -f -a "deployment" -d 'Manage deployments of a Shuttle service'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and not __fish_seen_subcommand_from init run deploy deployment status stop logs project resource clean login logout generate feedback help" -f -a "status" -d 'View the status of a Shuttle service'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and not __fish_seen_subcommand_from init run deploy deployment status stop logs project resource clean login logout generate feedback help" -f -a "stop" -d 'Stop this Shuttle service'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and not __fish_seen_subcommand_from init run deploy deployment status stop logs project resource clean login logout generate feedback help" -f -a "logs" -d 'View the logs of a deployment in this Shuttle service'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and not __fish_seen_subcommand_from init run deploy deployment status stop logs project resource clean login logout generate feedback help" -f -a "project" -d 'List or manage projects on Shuttle'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and not __fish_seen_subcommand_from init run deploy deployment status stop logs project resource clean login logout generate feedback help" -f -a "resource" -d 'Manage resources of a Shuttle project'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and not __fish_seen_subcommand_from init run deploy deployment status stop logs project resource clean login logout generate feedback help" -f -a "clean" -d 'Remove cargo build artifacts in the Shuttle environment'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and not __fish_seen_subcommand_from init run deploy deployment status stop logs project resource clean login logout generate feedback help" -f -a "login" -d 'Login to the Shuttle platform'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and not __fish_seen_subcommand_from init run deploy deployment status stop logs project resource clean login logout generate feedback help" -f -a "logout" -d 'Log out of the Shuttle platform'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and not __fish_seen_subcommand_from init run deploy deployment status stop logs project resource clean login logout generate feedback help" -f -a "generate" -d 'Generate shell completions and man page'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and not __fish_seen_subcommand_from init run deploy deployment status stop logs project resource clean login logout generate feedback help" -f -a "feedback" -d 'Open an issue on GitHub and provide feedback'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and not __fish_seen_subcommand_from init run deploy deployment status stop logs project resource clean login logout generate feedback help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and __fish_seen_subcommand_from deployment" -f -a "list" -d 'List all the deployments for a service'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and __fish_seen_subcommand_from deployment" -f -a "status" -d 'View status of a deployment'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and __fish_seen_subcommand_from deployment" -f -a "stop" -d 'BETA: Stop running deployment(s)'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and __fish_seen_subcommand_from project" -f -a "start" -d 'Create an environment for this project on Shuttle'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and __fish_seen_subcommand_from project" -f -a "status" -d 'Check the status of this project\'s environment on Shuttle'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and __fish_seen_subcommand_from project" -f -a "stop" -d 'Destroy this project\'s environment (container) on Shuttle'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and __fish_seen_subcommand_from project" -f -a "restart" -d 'Destroy and create an environment for this project on Shuttle'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and __fish_seen_subcommand_from project" -f -a "list" -d 'List all projects you have access to'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and __fish_seen_subcommand_from project" -f -a "delete" -d 'Delete a project and all linked data'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and __fish_seen_subcommand_from resource" -f -a "list" -d 'List all the resources for a project'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and __fish_seen_subcommand_from resource" -f -a "delete" -d 'Delete a resource'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and __fish_seen_subcommand_from generate" -f -a "shell" -d 'Generate shell completions'
complete -c cargo-shuttle -n "__fish_cargo_shuttle_using_subcommand help; and __fish_seen_subcommand_from generate" -f -a "manpage" -d 'Generate man page to the standard output'
